@@ -1,38 +1,29 @@
 const t = require('tap')
-const requireInject = require('require-inject')
+const log = require('../../../lib/utils/log-shim')
 
-const log = require('npmlog')
-log.level = 'warn'
+const _level = log.level
+t.beforeEach(() => log.level = 'warn')
+t.teardown(() => log.level = _level)
 
 t.cleanSnapshot = str => str.replace(/in [0-9]+m?s/g, 'in {TIME}')
 
 const settings = {
   fund: true,
 }
-const npmock = {
+const npm = {
   started: Date.now(),
   flatOptions: settings,
 }
-const getReifyOutput = tester =>
-  requireInject(
-    '../../../lib/utils/reify-output.js',
-    {
-      '../../../lib/npm.js': npmock,
-      '../../../lib/utils/output.js': tester,
-    }
-  )
-
+const reifyOutput = require('../../../lib/utils/reify-output.js')
 t.test('missing info', (t) => {
   t.plan(1)
-  const reifyOutput = getReifyOutput(
-    out => t.doesNotHave(
-      out,
-      'looking for funding',
-      'should not print fund message if missing info'
-    )
+  npm.output = out => t.notMatch(
+    out,
+    'looking for funding',
+    'should not print fund message if missing info'
   )
 
-  reifyOutput({
+  reifyOutput(npm, {
     actualTree: {
       children: [],
     },
@@ -44,15 +35,13 @@ t.test('missing info', (t) => {
 
 t.test('even more missing info', t => {
   t.plan(1)
-  const reifyOutput = getReifyOutput(
-    out => t.doesNotHave(
-      out,
-      'looking for funding',
-      'should not print fund message if missing info'
-    )
+  npm.output = out => t.notMatch(
+    out,
+    'looking for funding',
+    'should not print fund message if missing info'
   )
 
-  reifyOutput({
+  reifyOutput(npm, {
     actualTree: {
       children: [],
     },
@@ -61,19 +50,17 @@ t.test('even more missing info', t => {
 
 t.test('single package', (t) => {
   t.plan(1)
-  const reifyOutput = getReifyOutput(
-    out => {
-      if (out.endsWith('looking for funding')) {
-        t.match(
-          out,
-          '1 package is looking for funding',
-          'should print single package message'
-        )
-      }
+  npm.output = out => {
+    if (out.endsWith('looking for funding')) {
+      t.match(
+        out,
+        '1 package is looking for funding',
+        'should print single package message'
+      )
     }
-  )
+  }
 
-  reifyOutput({
+  reifyOutput(npm, {
     // a report with an error is the same as no report at all, if
     // the command is not 'audit'
     auditReport: {
@@ -111,14 +98,13 @@ t.test('no message when funding config is false', (t) => {
     settings.fund = true
   })
   settings.fund = false
-  const reifyOutput = getReifyOutput(
-    out => {
-      if (out.endsWith('looking for funding'))
-        t.fail('should not print funding info', { actual: out })
+  npm.output = out => {
+    if (out.endsWith('looking for funding')) {
+      t.fail('should not print funding info', { actual: out })
     }
-  )
+  }
 
-  reifyOutput({
+  reifyOutput(npm, {
     actualTree: {
       name: 'foo',
       package: {
@@ -148,19 +134,17 @@ t.test('no message when funding config is false', (t) => {
 
 t.test('print appropriate message for many packages', (t) => {
   t.plan(1)
-  const reifyOutput = getReifyOutput(
-    out => {
-      if (out.endsWith('looking for funding')) {
-        t.match(
-          out,
-          '3 packages are looking for funding',
-          'should print single package message'
-        )
-      }
+  npm.output = out => {
+    if (out.endsWith('looking for funding')) {
+      t.match(
+        out,
+        '3 packages are looking for funding',
+        'should print single package message'
+      )
     }
-  )
+  }
 
-  reifyOutput({
+  reifyOutput(npm, {
     actualTree: {
       name: 'foo',
       package: {
@@ -206,44 +190,168 @@ t.test('print appropriate message for many packages', (t) => {
   })
 })
 
-t.test('no output when silent', t => {
-  const reifyOutput = getReifyOutput(out => {
-    t.fail('should not get output when silent', { actual: out })
-  })
-  t.teardown(() => log.level = 'warn')
-  log.level = 'silent'
-  reifyOutput({
-    actualTree: { inventory: { size: 999 }, children: [] },
-    auditReport: {
-      toJSON: () => {
-        throw new Error('this should not get called')
-      },
-      vulnerabilities: {},
-      metadata: {
-        vulnerabilities: {
-          total: 99,
-        },
+t.test('showing and not showing audit report', async t => {
+  const auditReport = {
+    toJSON: () => auditReport,
+    auditReportVersion: 2,
+    vulnerabilities: {
+      minimist: {
+        name: 'minimist',
+        severity: 'low',
+        via: [
+          {
+            id: 1179,
+            url: 'https://npmjs.com/advisories/1179',
+            title: 'Prototype Pollution',
+            severity: 'low',
+            vulnerable_versions: '<0.2.1 || >=1.0.0 <1.2.3',
+          },
+        ],
+        effects: [],
+        range: '<0.2.1 || >=1.0.0 <1.2.3',
+        nodes: [
+          'node_modules/minimist',
+        ],
+        fixAvailable: true,
       },
     },
-    diff: {
-      children: [
-        { action: 'ADD', ideal: { location: 'loc' } },
-      ],
+    metadata: {
+      vulnerabilities: {
+        info: 0,
+        low: 1,
+        moderate: 0,
+        high: 0,
+        critical: 0,
+        total: 1,
+      },
+      dependencies: {
+        prod: 1,
+        dev: 0,
+        optional: 0,
+        peer: 0,
+        peerOptional: 0,
+        total: 1,
+      },
     },
+  }
+
+  t.test('no output when silent', t => {
+    npm.output = out => {
+      t.fail('should not get output when silent', { actual: out })
+    }
+    log.level = 'silent'
+    reifyOutput(npm, {
+      actualTree: { inventory: { size: 999 }, children: [] },
+      auditReport,
+      diff: {
+        children: [
+          { action: 'ADD', ideal: { location: 'loc' } },
+        ],
+      },
+    })
+    t.end()
   })
+
+  t.test('output when not silent', t => {
+    const OUT = []
+    npm.output = out => {
+      OUT.push(out)
+    }
+    reifyOutput(npm, {
+      actualTree: { inventory: new Map(), children: [] },
+      auditReport,
+      diff: {
+        children: [
+          { action: 'ADD', ideal: { location: 'loc' } },
+        ],
+      },
+    })
+    t.match(OUT.join('\n'), /Run `npm audit` for details\.$/, 'got audit report')
+    t.end()
+  })
+
+  for (const json of [true, false]) {
+    t.test(`json=${json}`, t => {
+      t.teardown(() => {
+        delete npm.flatOptions.json
+      })
+      npm.flatOptions.json = json
+      t.test('set exit code when cmd is audit', t => {
+        npm.output = () => {}
+        const { exitCode } = process
+        const { command } = npm
+        npm.flatOptions.auditLevel = 'low'
+        t.teardown(() => {
+          delete npm.flatOptions.auditLevel
+          npm.command = command
+          // only set exitCode back if we're passing tests
+          if (t.passing()) {
+            process.exitCode = exitCode
+          }
+        })
+
+        process.exitCode = 0
+        npm.command = 'audit'
+        reifyOutput(npm, {
+          actualTree: { inventory: new Map(), children: [] },
+          auditReport,
+          diff: {
+            children: [
+              { action: 'ADD', ideal: { location: 'loc' } },
+            ],
+          },
+        })
+
+        t.equal(process.exitCode, 1, 'set exit code')
+        t.end()
+      })
+
+      t.test('do not set exit code when cmd is install', t => {
+        npm.output = () => {}
+        const { exitCode } = process
+        const { command } = npm
+        npm.flatOptions.auditLevel = 'low'
+        t.teardown(() => {
+          delete npm.flatOptions.auditLevel
+          npm.command = command
+          // only set exitCode back if we're passing tests
+          if (t.passing()) {
+            process.exitCode = exitCode
+          }
+        })
+
+        process.exitCode = 0
+        npm.command = 'install'
+        reifyOutput(npm, {
+          actualTree: { inventory: new Map(), children: [] },
+          auditReport,
+          diff: {
+            children: [
+              { action: 'ADD', ideal: { location: 'loc' } },
+            ],
+          },
+        })
+
+        t.equal(process.exitCode, 0, 'did not set exit code')
+        t.end()
+      })
+      t.end()
+    })
+  }
+
   t.end()
 })
 
 t.test('packages changed message', t => {
   const output = []
-  const reifyOutput = getReifyOutput(out => {
+  npm.output = out => {
     output.push(out)
-  })
+  }
 
   // return a test function that builds up the mock and snapshots output
   const testCase = (t, added, removed, changed, audited, json, command) => {
     settings.json = json
-    npmock.command = command
+    npm.command = command
     const mock = {
       actualTree: {
         inventory: { size: audited, has: () => true },
@@ -264,11 +372,13 @@ t.test('packages changed message', t => {
         ],
       },
     }
-    for (let i = 0; i < added; i++)
+    for (let i = 0; i < added; i++) {
       mock.diff.children.push({ action: 'ADD', ideal: { location: 'loc' } })
+    }
 
-    for (let i = 0; i < removed; i++)
+    for (let i = 0; i < removed; i++) {
       mock.diff.children.push({ action: 'REMOVE', actual: { location: 'loc' } })
+    }
 
     for (let i = 0; i < changed; i++) {
       const actual = { location: 'loc' }
@@ -276,7 +386,7 @@ t.test('packages changed message', t => {
       mock.diff.children.push({ action: 'CHANGE', actual, ideal })
     }
     output.length = 0
-    reifyOutput(mock)
+    reifyOutput(npm, mock)
     t.matchSnapshot(output.join('\n'), JSON.stringify({
       added,
       removed,
@@ -291,8 +401,9 @@ t.test('packages changed message', t => {
     for (const removed of [0, 1, 2]) {
       for (const changed of [0, 1, 2]) {
         for (const audited of [0, 1, 2]) {
-          for (const json of [true, false])
+          for (const json of [true, false]) {
             cases.push([added, removed, changed, audited, json, 'install'])
+          }
         }
       }
     }
@@ -303,8 +414,9 @@ t.test('packages changed message', t => {
   cases.push([0, 0, 0, 2, false, 'audit'])
 
   t.plan(cases.length)
-  for (const [added, removed, changed, audited, json, command] of cases)
+  for (const [added, removed, changed, audited, json, command] of cases) {
     testCase(t, added, removed, changed, audited, json, command)
+  }
 
   t.end()
 })
@@ -312,11 +424,9 @@ t.test('packages changed message', t => {
 t.test('added packages should be looked up within returned tree', t => {
   t.test('has added pkg in inventory', t => {
     t.plan(1)
-    const reifyOutput = getReifyOutput(
-      out => t.matchSnapshot(out)
-    )
+    npm.output = out => t.matchSnapshot(out)
 
-    reifyOutput({
+    reifyOutput(npm, {
       actualTree: {
         name: 'foo',
         inventory: {
@@ -333,11 +443,9 @@ t.test('added packages should be looked up within returned tree', t => {
 
   t.test('missing added pkg in inventory', t => {
     t.plan(1)
-    const reifyOutput = getReifyOutput(
-      out => t.matchSnapshot(out)
-    )
+    npm.output = out => t.matchSnapshot(out)
 
-    reifyOutput({
+    reifyOutput(npm, {
       actualTree: {
         name: 'foo',
         inventory: {
